@@ -1,10 +1,12 @@
 #!/usr/bin/env python
 """
 Entry point for LedFx.
-To run this script for development purposes use:
 
-    poetry install
-    poetry run ledfx
+WARNING WARNING WARNING WARNING WARNING WARNING WARNING WARNING WARNING
+WARNING                                                         WARNING
+WARNING  ⚠️⚠️⚠️ DO NOT USE SOUNDDEVICE WITHIN MAIN.PY ⚠️⚠️⚠️ WARNING
+WARNING                                                         WARNING
+WARNING WARNING WARNING WARNING WARNING WARNING WARNING WARNING WARNING
 
 """
 
@@ -201,6 +203,13 @@ def parse_args():
         help="Launch LedFx and then exit after 5 seconds to sanity check the install",
     )
 
+    parser.add_argument(
+        "--generate-typescript-types",
+        dest="generate_typescript_types",
+        action="store_true",
+        help="Generate TypeScript types for the API and exit",
+    )
+
     parser.add_argument(
         "--clear-config",
         dest="clear_config",
@@ -215,11 +224,20 @@ def parse_args():
         help="Launch LedFx, load the config, clear all active effects on all virtuals. Effect configurations are persisted, just turned off",
     )
 
+    parser.add_argument(
+        "--pause-all",
+        dest="pause_all",
+        action="store_true",
+        help="Start Ledfx with all virtuals paused",
+    )
+
     return parser.parse_args()
 
 
 def main():
-    """Main entry point allowing external calls"""
+    """
+    Main entry point allowing external calls
+    """
 
     args = parse_args()
     config_helpers.ensure_config_directory(args.config)
@@ -305,9 +323,10 @@ def entry_point(icon=None):
             clear_config=args.clear_config,
             clear_effects=args.clear_effects,
             offline_mode=args.offline_mode,
+            generate_typescript_types=args.generate_typescript_types,
         )
 
-        exit_code = ledfx.start(open_ui=args.open_ui)
+        exit_code = ledfx.start(open_ui=args.open_ui, pause_all=args.pause_all)
 
     if icon:
         icon.stop()
