@@ -5,6 +5,7 @@ from aiohttp import web
 
 from ledfx.api import RestEndpoint
 from ledfx.config import save_config
+from ledfx.effects import DummyEffect
 from ledfx.events import SceneActivatedEvent
 from ledfx.utils import generate_id
 
@@ -36,7 +37,7 @@ class ScenesEndpoint(RestEndpoint):
         except JSONDecodeError:
             return await self.json_decode_error()
 
-        scene_id = data.get("id")
+        scene_id = generate_id(data.get("id"))
         if scene_id is None:
             return await self.invalid_request(
                 'Required attribute "id" was not provided'
@@ -82,7 +83,7 @@ class ScenesEndpoint(RestEndpoint):
         if action not in ["activate", "activate_in", "deactivate", "rename"]:
             return await self.invalid_request(f'Invalid action "{action}"')
 
-        scene_id = data.get("id")
+        scene_id = generate_id(data.get("id"))
         if scene_id is None:
             return await self.invalid_request(
                 'Required attribute "id" was not provided'
@@ -201,7 +202,19 @@ class ScenesEndpoint(RestEndpoint):
 
             return await self.invalid_request(error_message)
 
-        scene_id = generate_id(scene_name)
+        scene_id = data.get("id")
+
+        if not scene_id:
+            # this is a create, make sure it is deduped
+            dupe_id = generate_id(scene_name)
+            dupe_index = 1
+            scene_id = dupe_id
+            while scene_id in self._ledfx.config["scenes"].keys():
+                scene_id = f"{dupe_id}-{dupe_index}"
+                dupe_index = dupe_index + 1
+        else:
+            # this is an overwrite scenario, just sanitize scene_id
+            scene_id = generate_id(scene_id)
 
         scene_config = {}
         scene_config["name"] = scene_name
@@ -216,9 +229,16 @@ class ScenesEndpoint(RestEndpoint):
             for virtual in self._ledfx.virtuals.values():
                 effect = {}
                 if virtual.active_effect:
-                    effect["type"] = virtual.active_effect.type
-                    effect["config"] = virtual.active_effect.config
-                    # effect['name'] = virtual.active_effect.name
+                    # prevent crash from trying to save copy / span transitions
+                    # which appear active even when the virtual is not!!!
+                    if not isinstance(virtual.active_effect, DummyEffect):
+                        effect["type"] = virtual.active_effect.type
+                        effect["config"] = virtual.active_effect.config
+                        # effect['name'] = virtual.active_effect.name
+                    else:
+                        _LOGGER.debug(
+                            f"Skipping DummyEffect for virtual {virtual.id}"
+                        )
                 scene_config["virtuals"][virtual.id] = effect
         else:
             virtuals = data.get("virtuals")
