@@ -43,6 +43,9 @@ CORE_CONFIG_KEYS_NO_RESTART = [
     "user_presets",
     "visualisation_maxlen",
     "visualisation_fps",
+    "flush_on_deactivate",
+    "ui_brightness_boost",
+    "startup_scene_id",
 ]
 # Collection of keys that are used for visualisation configuration - used to check if we need to restart the visualisation event listeners
 VISUALISATION_CONFIG_KEYS = [
@@ -104,6 +107,7 @@ WLED_CONFIG_SCHEMA = vol.Schema(
 CORE_CONFIG_SCHEMA = vol.Schema(
     {
         vol.Optional("host", default="0.0.0.0"): str,
+        vol.Optional("hosts", default=[]): list,
         vol.Optional("port", default=8888): int,
         vol.Optional("port_s", default=8443): int,
         vol.Optional("dev_mode", default=False): bool,
@@ -123,7 +127,7 @@ CORE_CONFIG_SCHEMA = vol.Schema(
             int, vol.Range(1, 60)
         ),
         vol.Optional("visualisation_maxlen", default=81): vol.All(
-            int, vol.Range(5, 4096)
+            int, vol.Range(5, 65536)
         ),
         vol.Optional(
             "global_transitions",
@@ -134,6 +138,7 @@ CORE_CONFIG_SCHEMA = vol.Schema(
         vol.Optional("user_gradients", default={}): dict,
         vol.Optional("scan_on_startup", default=False): bool,
         vol.Optional("create_segments", default=False): bool,
+        vol.Optional("flush_on_deactivate", default=False): bool,
         vol.Optional("wled_preferences", default={}): dict,
         vol.Optional(
             "configuration_version", default=CONFIGURATION_VERSION
@@ -141,6 +146,10 @@ CORE_CONFIG_SCHEMA = vol.Schema(
         vol.Optional("global_brightness", default=1.0): vol.All(
             vol.Coerce(float), vol.Range(0, 1.0)
         ),
+        vol.Optional("ui_brightness_boost", default=0.0): vol.All(
+            vol.Coerce(float), vol.Range(0, 1.0)
+        ),
+        vol.Optional("startup_scene_id", default=""): str,
     },
     extra=vol.ALLOW_EXTRA,
 )
@@ -582,6 +591,33 @@ def migrate_config(old_config):
                 "FXMatrix devices are no longer supported. Add it as plain UDP or WLED."
             )
             continue
+        if (
+            device["type"].lower() == "artnet"
+            and "device_repeat" in device["config"]
+        ):
+            device["config"]["pixels_per_device"] = device["config"].pop(
+                "device_repeat"
+            )
+
+        # Migrate ArtNet output_mode → rgb_order + white_mode
+        if device["type"].lower() == "artnet":
+            cfg = device.get("config", {})
+            if "output_mode" in cfg:
+                old_mode = cfg.pop("output_mode")
+                mapping = {
+                    "RGB": ("RGB", "None"),
+                    "RGBW No White": ("RGB", "Zero"),
+                    "RGBW Accurate": ("RGB", "Accurate"),
+                    "RGBW Brighter": ("RGB", "Brighter"),
+                }
+                rgb_order, white_mode = mapping.get(old_mode, ("RGB", "None"))
+                cfg["rgb_order"] = rgb_order
+                cfg["white_mode"] = white_mode
+                _LOGGER.warning(
+                    f"Migrated ArtNet device '{device.get('name', '')}' from output_mode={old_mode} "
+                    f"to rgb_order={rgb_order}, white_mode={white_mode}"
+                )
+
         device.pop("effect", None)
         new_config["devices"].append(device)
 
@@ -722,6 +758,13 @@ def migrate_config(old_config):
             "name": scenes[scene_id]["name"],
         }
 
+    # if audio:min_volume is present and greater than 1 then set to a default of
+    # 0.2, old range was 0 to 10, but effective range is only 0 to 1, anything
+    # >= 1 will just squelch all audio, source of error for some users while
+    # trying to make audio work and blindly pushing sliders
+    if new_config.get("audio", {}).get("min_volume", 0) > 1:
+        new_config["audio"]["min_volume"] = 0.2
+
     _LOGGER.warning("Finished migrating config.")
     return new_config
 
