@@ -1,5 +1,6 @@
 import logging
 import threading
+import timeit
 
 # from ledfx.effects.audio import FREQUENCY_RANGES
 from functools import lru_cache
@@ -8,7 +9,8 @@ import numpy as np
 import voluptuous as vol
 from numpy.typing import NDArray
 
-from ledfx.color import hsv_to_rgb, parse_color, validate_color
+from ledfx.color import LEDFX_COLORS, hsv_to_rgb, parse_color, validate_color
+from ledfx.effects.utils.logsec_helper import LogSecHelper
 from ledfx.utils import BaseRegistry, RegistryLoader
 
 _LOGGER = logging.getLogger(__name__)
@@ -273,9 +275,8 @@ class Effect(BaseRegistry):
     NAME = ""
     # over ride in effect children to hide existing keys from UI
     HIDDEN_KEYS = None
-    # over ride in effect children AND add an "advanced" bool to schema
-    # to show or hide in UI
-    ADVANCED_KEYS = None
+    # extend in effect children
+    ADVANCED_KEYS = ["diag"]
     # over ride in effect children to allow edit and show others
     PERMITTED_KEYS = None
     _config = None
@@ -313,6 +314,13 @@ class Effect(BaseRegistry):
                 description="Brightness of the background color",
                 default=1.0,
             ): vol.All(vol.Coerce(float), vol.Range(min=0.0, max=1.0)),
+            vol.Optional(
+                "diag", description="Enable diagnostic logging", default=False
+            ): bool,
+            vol.Optional(
+                "advanced",
+                description=False,
+            ): bool,
         }
     )
 
@@ -320,6 +328,10 @@ class Effect(BaseRegistry):
         self._ledfx = ledfx
         self._config = {}
         self.lock = threading.Lock()
+        self.logsec = LogSecHelper(self)
+        self.passed = 0.0
+        self._last_frame_time = timeit.default_timer()
+        self.now = self._last_frame_time
         self.update_config(config)
 
     def __del__(self):
@@ -386,10 +398,19 @@ class Effect(BaseRegistry):
             else:
                 self._config = validated_config
 
-            self._bg_color = (
-                np.array(parse_color(self._config["background_color"]))
-                * self._config["background_brightness"]
-            )
+            bg_color = parse_color(self._config["background_color"])
+            # if bg color is black then we don't need to do anything with it
+            self.bg_color_use = bg_color != parse_color(LEDFX_COLORS["black"])
+
+            if self.bg_color_use:
+                self._bg_color = (
+                    np.array(bg_color) * self._config["background_brightness"]
+                )
+
+            self.flip = self._config["flip"]
+            self.mirror = self._config["mirror"]
+            self.brightness = self._config["brightness"]
+            self.logsec.diag = self._config.get("diag", False)
 
             def inherited(cls, method):
                 if hasattr(cls, method) and hasattr(super(cls, cls), method):
@@ -421,7 +442,9 @@ class Effect(BaseRegistry):
         with self.lock:
             # its possible we were waiting on the effect being deactivated
             if self._active:
+                self.log_sec()
                 self.render()
+                self.try_log()
 
     def render(self):
         """
@@ -448,18 +471,26 @@ class Effect(BaseRegistry):
                     config = self._config
 
                     # Apply some of the base output filters if necessary
-                    if config["flip"]:
+                    if self.flip:
                         pixels = np.flipud(pixels)
-                    if config["mirror"]:
-                        pixels = np.concatenate(
-                            (pixels[-1 + len(pixels) % -2 :: -2], pixels[::2])
+
+                    if self.mirror:
+                        # concatenate the pixels for mirror, then take the max of adjacent pixels
+                        # prevents average dimming and is best compromise, removes flicker
+                        # inherently symetrical
+                        mirrored_pixels = np.concatenate(
+                            (pixels[::-1], pixels)
                         )
-                    if config["background_color"]:
+                        pixels = np.maximum(
+                            mirrored_pixels[::2], mirrored_pixels[1::2]
+                        )
+
+                    if self.bg_color_use:
                         pixels += self._bg_color
-                    if config["brightness"] is not None:
+                    if self.brightness is not None:
                         np.multiply(
                             pixels,
-                            config["brightness"],
+                            self.brightness,
                             out=pixels,
                             casting="unsafe",
                         )
@@ -504,6 +535,15 @@ class Effect(BaseRegistry):
     def name(self):
         return self.NAME
 
+    def log_sec(self):
+        self.now = timeit.default_timer()
+        self.passed = self.now - self._last_frame_time
+        self._last_frame_time = self.now
+        self.logsec.log_sec(self.now)
+
+    def try_log(self):
+        return self.logsec.try_log()
+
 
 class Effects(RegistryLoader):
     """Thin wrapper around the effect registry that manages effects"""
