@@ -21,6 +21,7 @@ from collections.abc import MutableMapping
 from functools import lru_cache
 from importlib import metadata
 from itertools import chain
+from logging.handlers import QueueHandler
 from platform import (
     processor,
     python_build,
@@ -892,7 +893,7 @@ class UserDefaultCollection(MutableMapping):
         return len(self._default_vals) + len(self._user_vals)
 
 
-class RollingQueueHandler(logging.handlers.QueueHandler):
+class RollingQueueHandler(QueueHandler):
     """
     A custom logging handler that extends the QueueHandler class.
     This handler enqueues log records into a queue, and if the queue is full,
