@@ -1,6 +1,5 @@
 import os
 import shutil
-import subprocess
 from pathlib import Path
 from sys import platform
 
@@ -26,15 +25,10 @@ def copy_lib():
             )
             break
 
-    # If not in site-packages, means it's a poetry build, so get env path from
+    # If not in site-packages, means it's a development environment, so get env path from the .venv
     if not lib_path:
-        env_path = (
-            subprocess.check_output(["poetry", "env", "info", "--path"])
-            .decode("utf-8")
-            .strip()
-        )
         lib_path = os.path.join(
-            env_path,
+            ".venv",
             "Lib",
             "site-packages",
             "_sounddevice_data",
